@@ -53,7 +53,9 @@ pub struct ListChapter<'a> {
     pub title: Option<&'a str>,
     #[builder(setter(each = "add_group"))]
     pub groups: Vec<&'a Uuid>,
-    pub uploader: Option<&'a Uuid>,
+    #[serde(rename = "uploader")]
+    #[builder(setter(each = "uploader"))]
+    pub uploaders: Vec<&'a Uuid>,
     #[serde(rename = "manga")]
     pub manga_id: Option<&'a Uuid>,
     #[serde(rename = "volume")]
@@ -73,6 +75,12 @@ pub struct ListChapter<'a> {
     pub excluded_original_languages: Vec<Language>,
     #[builder(setter(each = "add_content_rating"))]
     pub content_rating: Vec<ContentRating>,
+    /// Groups to exclude from the results.
+    #[builder(setter(each = "excluded_group"))]
+    pub excluded_groups: Vec<&'a Uuid>,
+    /// Uploaders to exclude from the results.
+    #[builder(setter(each = "excluded_uploader"))]
+    pub excluded_uploaders: Vec<&'a Uuid>,
     /// Flag to include future chapter updates in the results.
     ///
     /// Default: `IncludeFutureUpdates::Include` (1)
@@ -152,6 +160,7 @@ mod tests {
                         "title": chapter_title,
                         "volume": "1",
                         "chapter": "1.5",
+                        "pages": 4,
                         "translatedLanguage": "en",
                         "uploader": uploader_id,
                         "version": 1,
@@ -188,6 +197,7 @@ mod tests {
         assert_eq!(chapter.attributes.title, chapter_title);
         assert_eq!(chapter.attributes.volume, Some("1".to_string()));
         assert_eq!(chapter.attributes.chapter, Some("1.5".to_string()));
+        assert_eq!(chapter.attributes.pages, 4);
         assert_eq!(chapter.attributes.translated_language, Language::English);
         assert_eq!(chapter.attributes.uploader, Some(uploader_id));
         assert_eq!(chapter.attributes.version, 1);
