@@ -17,9 +17,11 @@ mod manga_read_markers;
 mod manga_reading_status;
 mod manga_reading_statuses;
 mod manga_relation;
+mod ratings;
 mod refresh_token_response;
 mod report;
 mod scanlation_group;
+mod statistics;
 mod tag;
 #[cfg(feature = "upload")]
 mod upload_session;
@@ -53,9 +55,11 @@ pub(crate) use manga_read_markers::{MangaReadMarkers, UngroupedMangaReadMarkers}
 pub(crate) use manga_reading_status::MangaReadingStatus;
 pub(crate) use manga_reading_statuses::MangaReadingStatuses;
 pub(crate) use manga_relation::MangaRelationAttributes;
+pub(crate) use ratings::RatingsList;
 pub(crate) use refresh_token_response::RefreshTokenResponse;
 pub(crate) use report::ReportReasonAttributes;
 pub(crate) use scanlation_group::ScanlationGroupAttributes;
+pub(crate) use statistics::manga::MangaStatisticsObject;
 pub(crate) use tag::TagAttributes;
 #[cfg(feature = "upload")]
 pub(crate) use upload_session::UploadSessionResponse;
@@ -110,6 +114,10 @@ pub type MangaReadingStatusesResponse = Result<MangaReadingStatuses>;
 pub type MangaRelationObject = ApiObject<MangaRelationAttributes>;
 pub type MangaRelationListResponse = Result<Results<MangaRelationObject>>;
 
+pub type MangaStatisticsResponse = Result<MangaStatisticsObject>;
+
+pub type RatingsResponse = Result<RatingsList>;
+
 pub type ReportReasonObject = ApiObjectNoRelationships<ReportReasonAttributes>;
 pub type ReportReasonListResponse = Result<Results<ReportReasonObject>>;
 
