@@ -33,6 +33,12 @@ pub struct AuthorAttributes {
     pub tumblr: Option<Url>,
     /// <https://www.youtube.com>
     pub youtube: Option<Url>,
+    /// [https://weibo.cn/u/](https://weibo.cn)
+    /// or
+    /// [https://m.weibo.cn/u/](https://m.weibo.cn)
+    pub weibo: Option<Url>,
+    /// <https://blog.naver.com/>
+    pub naver: Option<Url>,
     pub website: Option<Url>,
     pub version: u32,
     /// Datetime in `YYYY-MM-DDTHH:MM:SS+HH:MM` format.
