@@ -17,12 +17,13 @@ pub struct ChapterAttributes {
     pub volume: Option<String>,
     /// Chapter number in the manga.
     pub chapter: Option<String>,
+    /// Count of readable images for this chapter.
+    pub pages: u32,
     /// Language the text is in.
     pub translated_language: Language,
     /// User ID (UUID) who uploaded the chapter.
     pub uploader: Option<Uuid>,
-    /// While `hash`, `data` and `dataSaver` attributes are empty,
-    /// denotes a chapter that links to an external source.
+    /// Denotes a chapter that links to an external source.
     pub external_url: Option<Url>,
     pub version: u32,
     /// Datetime in `YYYY-MM-DDTHH:MM:SS+HH:MM` format.
