@@ -35,6 +35,7 @@
 
 use derive_builder::Builder;
 use serde::Serialize;
+use uuid::Uuid;
 
 use crate::types::{
     ContentRating, IncludeFutureUpdates, Language, MangaDexDateTime, MangaFeedSortOrder,
@@ -47,7 +48,7 @@ use crate::HttpClientRef;
 #[serde(rename_all = "camelCase")]
 #[builder(setter(into, strip_option), pattern = "owned", default)]
 #[non_exhaustive]
-pub struct GetFollowedMangaFeed {
+pub struct GetFollowedMangaFeed<'a> {
     /// This should never be set manually as this is only for internal use.
     #[doc(hidden)]
     #[serde(skip)]
@@ -69,6 +70,12 @@ pub struct GetFollowedMangaFeed {
     pub excluded_original_language: Vec<Language>,
     #[builder(setter(each = "add_content_rating"))]
     pub content_rating: Vec<ContentRating>,
+    /// Groups to exclude from the results.
+    #[builder(setter(each = "excluded_group"))]
+    pub excluded_groups: Vec<&'a Uuid>,
+    /// Uploaders to exclude from the results.
+    #[builder(setter(each = "excluded_uploader"))]
+    pub excluded_uploaders: Vec<&'a Uuid>,
     /// Flag to include future chapter updates in the results.
     ///
     /// Default: `IncludeFutureUpdates::Include` (1)
@@ -90,7 +97,7 @@ pub struct GetFollowedMangaFeed {
 
 endpoint! {
     GET "/user/follows/manga/feed",
-    #[query auth] GetFollowedMangaFeed,
+    #[query auth] GetFollowedMangaFeed<'_>,
     #[flatten_result] ChapterListResponse
 }
 
@@ -156,6 +163,7 @@ mod tests {
                         "title": chapter_title,
                         "volume": "1",
                         "chapter": "1.5",
+                        "pages": 4,
                         "translatedLanguage": "en",
                         "uploader": uploader_id,
                         "version": 1,
